bayespy.inference.vmp.nodes.gaussian.GaussianGammaMoments.get_instance_converter
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaMoments.get_instance_converter